@@ -11,6 +11,8 @@
 #' climate variables.
 #' @param frequency frequency of the data requested (default = "daily", other
 #' options are "monthly" or "annual".
+#' @param mosaic which tile mosiac to source from (na = Northern America,
+#' hi = Hawaii, pr = Puerto Rico), defaults to "na".
 #' @param path directory where to store the downloaded data (default = tempdir())
 #' @param silent suppress the verbose output
 #' @param force \code{TRUE} or \code{FALSE} (default),
@@ -45,34 +47,24 @@
 #' # vignette. 
 #' }
 
-download_daymet_ncss = function(location = c(34, -82, 33.75, -81.75),
-                                 start = 1980,
-                                 end = 1980,
-                                 param = "tmin",
-                                 frequency = "daily",
-                                 path = tempdir(),
-                                 silent = FALSE,
-                                 force = FALSE){
+download_daymet_ncss <- function(
+  location = c(34, -82, 33.75, -81.75),
+  start = 1980,
+  end = 1980,
+  param = "tmin",
+  frequency = "daily",
+  mosaic = "na",
+  path = tempdir(),
+  silent = FALSE,
+  force = FALSE
+  ){
   # CRAN file policy
   if (identical(path, tempdir())){
     message("NOTE: data is stored in tempdir() ...")
   }
   
-  # base url path
-  base_url = "https://thredds.daac.ornl.gov/thredds/ncss/ornldaac"
-  
   # remove capitals from frequency
-  frequency = tolower(frequency)
-  
-  # set final url path depending on the frequency of the
-  # data requested
-  if(frequency == "monthly"){
-    base_url = sprintf("%s/%s", base_url, 1345)
-  } else if (frequency == "annual"){
-    base_url = sprintf("%s/%s", base_url, 1343)
-  } else {
-    base_url = sprintf("%s/%s", base_url, 1328)
-  }
+  frequency <- tolower(frequency)
   
   # check if there are enough coordinates specified
   if (length(location)!=4){
@@ -82,9 +74,9 @@ download_daymet_ncss = function(location = c(34, -82, 33.75, -81.75),
   # force the max year to be the current year or
   # current year - 1 (conservative)
   if (!force){
-    max_year = as.numeric(format(Sys.time(), "%Y")) - 1
+    max_year <- as.numeric(format(Sys.time(), "%Y")) - 1
   } else {
-    max_year = as.numeric(format(Sys.time(), "%Y"))
+    max_year <- as.numeric(format(Sys.time(), "%Y"))
   }
   
   # check validaty of the range of years to download
@@ -100,21 +92,21 @@ download_daymet_ncss = function(location = c(34, -82, 33.75, -81.75),
   }
   
   # if the year range is valid, create a string of valid years
-  year_range = seq(start, end, by = 1)
+  year_range <- seq(start, end, by = 1)
   
   # check the parameters we want to download in case of
   # ALL list all available parameters for each frequency
   if (any(grepl("ALL", toupper(param)))) {
     if (tolower(frequency) == "daily"){
-      param = c('vp','tmin','tmax','swe','srad','prcp','dayl')
+      param <- c('vp','tmin','tmax','swe','srad','prcp','dayl')
     } else {
-      param = c('vp','tmin','tmax','prcp')
+      param <- c('vp','tmin','tmax','prcp')
     }
   }
 
   # provide some feedback
   if(!silent){
-    cat('Creating a subset of the Daymet data
+    message('Creating a subset of the Daymet data
         be patient, this might take a while!\n')
   }
   
@@ -122,28 +114,39 @@ download_daymet_ncss = function(location = c(34, -82, 33.75, -81.75),
     for ( j in param ){
       
       if (frequency != "daily"){
-        if (j != "prcp"){
-          prefix = paste0(substr(frequency,1,3),"avg")
-        } else {
-          prefix = paste0(substr(frequency,1,3),"ttl")
+        
+        prefix <- ifelse(j != "prcp",
+          paste0(substr(frequency,1,3),"avg"),
+          paste0(substr(frequency,1,3),"ttl"))
+        
+        # create url string (varies per product / year)
+        url <- sprintf("%s/daymet_v3_%s_%s_%s_%s.nc4",
+                       ncss_server(frequency = frequency),
+                       j, prefix, i, mosaic)
+        
+        # create filename for the output file
+        daymet_file <- file.path(path, paste0(j,"_",prefix,"_",i,"_ncss.nc"))
+        
+      } else {
+        
+        # correction in naming conventions
+        if(mosaic == "hi"){
+          mosaic <- "hawaii"
+        } else if(mosaic == "pr"){
+          mosaic <- "puertorico"
         }
         
         # create url string (varies per product / year)
-        url = sprintf("%s/daymet_v3_%s_%s_%s_na.nc4", base_url, j, prefix, i)
-        
+        url <- sprintf("%s/%s/daymet_v3_%s_%s_%s.nc4",
+                       ncss_server(frequency = frequency),
+                       i, j, i, mosaic)
+
         # create filename for the output file
-        daymet_file = file.path(path, paste0(j,"_",prefix,"_",i,"_ncss.nc"))
-        
-      } else {
-        # create url string (varies per product / year)
-        url = sprintf("%s/%s/daymet_v3_%s_%s_na.nc4", base_url, i, j, i)
-        
-        # create filename for the output file
-        daymet_file = file.path(path,paste0(j,"_daily_",i,"_ncss.nc"))
+        daymet_file <- file.path(path,paste0(j,"_daily_",i,"_ncss.nc"))
       }
-      
-      # formulate query to pass to httr           
-      query = list(
+            
+      # formulate query to pass to httr
+      query <- list(
         "var" = "lat",
         "var" = "lon",
         "var" = j,
@@ -159,7 +162,7 @@ download_daymet_ncss = function(location = c(34, -82, 33.75, -81.75),
       
       # provide some feedback
       if(!silent){
-        cat(paste0('\nDownloading DAYMET subset: ',
+        message(paste0('\nDownloading DAYMET subset: ',
                   'year: ',i,
                   '; product: ',j,
                   '\n'))
@@ -167,25 +170,30 @@ download_daymet_ncss = function(location = c(34, -82, 33.75, -81.75),
       
       # download data, force binary data mode
       if(silent){
-        status = try(utils::capture.output(
-          httr::GET(url = url,
+        status <- httr::GET(url = url,
                     query = query,
-                    httr::write_disk(path = daymet_file, overwrite = TRUE))),
-                  silent = TRUE)
-      
+                    httr::write_disk(path = daymet_file,
+                                     overwrite = TRUE))
       } else {
-        status = try(httr::GET(url = url,
+        status <- httr::GET(url = url,
                                query = query,
                                httr::write_disk(path = daymet_file,
                                                 overwrite = TRUE),
-                               httr::progress()),
-                     silent = TRUE)
+                               httr::progress())
       }
       
       # error / stop on 400 error
-      if(inherits(status,"try-error")){
-        stop("Requested coverage exceeds 6GB file size limit!")
+      if(httr::http_error(status)){
+        
+        # remove bad file
+        file.remove(daymet_file)
+        
+        # report error
+        stop("Requested data download failed!\ 
+             Common issues involve a mismatch between\ 
+             the location and the mosaic used or downloads\ 
+             exceeding 6GB in size.", call. = FALSE)
       }
     }
   }
-}
\ No newline at end of file
+}
